@@ -1,16 +1,19 @@
 <?php
 
-class UpdateManagerDashboard {
+defined('ULICMS_ROOT') || exit('No direct script access allowed');
 
+use App\Packages\PackageManager;
+
+class UpdateManagerDashboard {
     public static function anyUpdateAvailable() {
         $pkg = new PackageManager();
         $modules = getAllModules();
         if (count($modules) > 0) {
             foreach ($modules as $module) {
-                $version = getModuleMeta($module, "version");
+                $version = getModuleMeta($module, 'version');
                 if ($version != null) {
                     $status = $pkg->checkForNewerVersionOfPackage($module);
-                    if (\UliCMS\Utils\VersionComparison\compare($status, $version, '>')) {
+                    if (\App\Utils\VersionComparison::compare($status, $version, '>')) {
                         return true;
                     }
                 }
@@ -20,11 +23,11 @@ class UpdateManagerDashboard {
         $themes = getAllThemes();
         if (count($themes) > 0) {
             foreach ($themes as $theme) {
-                $version = getThemeMeta($theme, "version");
+                $version = getThemeMeta($theme, 'version');
                 if ($version != null) {
-                    $theme = "theme-" . $theme;
+                    $theme = 'theme-' . $theme;
                     $status = $pkg->checkForNewerVersionOfPackage($theme);
-                    if (\UliCMS\Utils\VersionComparison\compare($status, $version, '>')) {
+                    if (\App\Utils\VersionComparison::compare($status, $version, '>')) {
                         return true;
                     }
                 }
@@ -33,5 +36,4 @@ class UpdateManagerDashboard {
 
         return false;
     }
-
 }
